@@ -7,7 +7,7 @@ developer = {"name": "정지효 (Jung Ji-Hyo)", "email": "cord0318@gmail.com", "
 key = {"right":"<ctrl>+v", "left":"<ctrl>+x"}
 
 def check_version():
-    version = "0.0.9"
+    version = "0.0.10"
     click.echo("autoclick " + version)
 
 cmd_list = ["set_autoclick_key (키 바꾸기)", "developer (개발자)", "friend (도와준 친구)"]
@@ -80,7 +80,7 @@ def main(delay, right_key, left_key, check_key, version, command):
     if delay:
         click.echo("Your delay : " + str(delay))
         click.echo("start autoclick . . .")
-        auto_click = AutoClick(delay, key["right"], key["left"])
+        auto_click = AutoClick(delay=delay, right_key=key["right"], left_key=key["left"])
         auto_click.run_autoclick()
 
 if __name__ == '__main__':
